// Defining constants and variables
const scalar Pi(3.14159265359);
const vector CofR = dict_.subDict("coordinateSystem").lookup("origin");
const scalar rhoInf = readScalar( dict_.subDict("variableRpm").lookup("rhoInf") );
const wordList patches = dict_.subDict("forcePatches").lookup(cellZoneNames[cellZoneI]);
const scalar Iz = readScalar(dict_.subDict("variableRpm").lookup("Iz"));
const scalar cutoffRpm = readScalar( dict_.subDict("variableRpm").lookup("cutoffRpm") );

scalar Pnom = readScalar( dict_.subDict("variableRpm").lookup("Pnom") );
scalar rpmNom = readScalar( dict_.subDict("variableRpm").lookup("rpmNom") );
scalar P;
scalar alpha;
scalar Mflow;
scalar Mpow;

// Calculate forces on patches defined in dynamicMeshDict
dictionary forcesDict;
forcesDict.add("patches", patches);
forcesDict.add("rhoName", "rhoInf");
forcesDict.add("rhoInf", rhoInf);
forcesDict.add("CofR", CofR);

forces F("forces", *this, forcesDict);
forces::forcesMoments fm = F.calcForcesMoment();

// Calculate Moment about z-axis form pressure and viscous forces
Mflow = fm.second().first().z()+fm.second().second().z();

// Apply moment if the rotational speed is higher than cutoff speed (because rpm->0 => Mpow->Inf)
if (abs(rpmOld) > abs(cutoffRpm))
{
    P = Pnom;
}
else 
{
    P = 0;
}

// Calculate the nominal moment from numinal power and rpm defined in dynamicMeshDict
Mpow = P/(rpmNom*Pi/30);

// Calculate angular acceleration and rpm (with accleration limited to 5 m/s2 for stability)
alpha = ( Mflow-Mpow )/Iz;
if (abs(alpha) > 5)
{
    if (pos(alpha))
    {
        alpha = 5;
    }
    else if (neg(alpha))
    {
        alpha = -5;
    }
}

rpm = rpmOld + ( (30/Pi)*alpha )*time().deltaT().value();
